aboutsummaryrefslogtreecommitdiff
path: root/ports/tinygltf
diff options
context:
space:
mode:
Diffstat (limited to 'ports/tinygltf')
-rw-r--r--ports/tinygltf/CONTROL3
-rw-r--r--ports/tinygltf/portfile.cmake8
2 files changed, 6 insertions, 5 deletions
diff --git a/ports/tinygltf/CONTROL b/ports/tinygltf/CONTROL
index ceba5f92b..c4581faa6 100644
--- a/ports/tinygltf/CONTROL
+++ b/ports/tinygltf/CONTROL
@@ -1,5 +1,6 @@
Source: tinygltf
Version: 2020-07-28
+Port-Version: 1
Homepage: https://github.com/syoyo/tinygltf
Description: A header only C++11 glTF 2.0 library.
-Build-Depends: stb, nlohmann-json \ No newline at end of file
+Build-Depends: stb, nlohmann-json
diff --git a/ports/tinygltf/portfile.cmake b/ports/tinygltf/portfile.cmake
index ef263046b..fbb2d2ff9 100644
--- a/ports/tinygltf/portfile.cmake
+++ b/ports/tinygltf/portfile.cmake
@@ -8,8 +8,8 @@ vcpkg_from_github(
)
# Put the licence file where vcpkg expects it
-file(COPY ${SOURCE_PATH}/LICENSE DESTINATION ${CURRENT_PACKAGES_DIR}/share/tinygltf/LICENSE)
-file(RENAME ${CURRENT_PACKAGES_DIR}/share/tinygltf/LICENSE ${CURRENT_PACKAGES_DIR}/share/tinygltf/copyright)
+# Copy the tinygltf header files and fix the path to json
+vcpkg_replace_string(${SOURCE_PATH}/tiny_gltf.h "#include \"json.hpp\"" "#include <nlohmann/json.hpp>")
+file(INSTALL ${SOURCE_PATH}/tiny_gltf.h DESTINATION ${CURRENT_PACKAGES_DIR}/include)
-# Copy the tinygltf header files
-file(COPY ${SOURCE_PATH}/tiny_gltf.h DESTINATION ${CURRENT_PACKAGES_DIR}/include)
+file(INSTALL ${SOURCE_PATH}/LICENSE DESTINATION ${CURRENT_PACKAGES_DIR}/share/${PORT} RENAME copyright)